==> v2.3.6.zip: ttv-lol-pro/README.md <==
<h1 align="center">
  <img alt="Icon" src="src/common/images/brand/icon.png" height="100" width="100" />
  <br />
  TTV LOL PRO
  <br />
</h1>

<div align="center">
  <a href="https://github.com/younesaassila/ttv-lol-pro/issues">
    <img
      alt="GitHub issues"
      src="https://img.shields.io/github/issues/younesaassila/ttv-lol-pro"
    />
  </a>
  <a href="https://github.com/younesaassila/ttv-lol-pro/stargazers">
    <img
      alt="GitHub stars"
      src="https://img.shields.io/github/stars/younesaassila/ttv-lol-pro"
    />
  </a>
  <a
    href="https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd"
  >
    <img
      alt="Chrome Web Store"
      src="https://img.shields.io/chrome-web-store/users/bpaoeijjlplfjbagceilcgbkcdjbomjd"
    />
  </a>
  <a href="https://addons.mozilla.org/addon/ttv-lol-pro/">
    <img alt="Mozilla Add-on" src="https://img.shields.io/amo/dw/ttv-lol-pro" />
  </a>
</div>

<div align="center">
  <a href="https://discord.gg/AmtFTPwsyH">
    <img
      alt="Discord server"
      src="https://dcbadge.vercel.app/api/server/AmtFTPwsyH"
    />
  </a>
</div>

<br />

<div align="center">
  <a
    href="https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd"
  >
    <img
      alt="Chrome Web Store"
      src="src/common/images/badges/chrome_web_store.png"
      height="50"
    />
  </a>
  <a href="https://addons.mozilla.org/addon/ttv-lol-pro/">
    <img
      alt="Firefox Add-ons"
      src="src/common/images/badges/firefox_addons.png"
      height="50"
    />
  </a>
</div>

<br />

> ℹ️ Looking for TTV LOL PRO v1? [Click here](https://github.com/younesaassila/ttv-lol-pro/tree/v1).

TTV LOL PRO removes most livestream ads from Twitch. This is free, don't expect it to be perfect.

TTV LOL PRO is a fork of TTV LOL that:

- uses an improved ad blocking method,
- uses standard HTTP proxies (thus improving proxy compatibility and your privacy),
- adds a stream status widget to the popup,
- lets you whitelist channels,
- lets you use your own proxies.

TTV LOL PRO does not remove banner ads, nor does it remove ads from VODs. For the best experience, we recommend using [uBlock Origin](https://ublockorigin.com/) alongside TTV LOL PRO.

Any questions? Please read the [wiki](https://wiki.cdn-perfprod.com/) first.

## Screenshots

<details>
  <summary>Popup (Firefox)</summary>
  <div align="center">
    <img
      alt="Popup (Firefox)"
      src="https://github.com/younesaassila/ttv-lol-pro/assets/47226184/722b2e22-50b0-4fc7-bd7b-61be2e1b592d"
      height="550"
    />
  </div>
</details>

<details>
  <summary>Options page (Firefox)</summary>
  <div align="center">
    <img
      alt="Options page (Firefox)"
      src="https://github.com/younesaassila/ttv-lol-pro/assets/47226184/83d96fcf-a8b1-4193-9dbe-232bf9d99529"
      height="550"
    />
  </div>
</details>

## Installation

> ⚠️ Please remove any other Twitch-specific ad blocker (this includes the [VAFT](https://github.com/pixeltris/TwitchAdSolutions#scripts) script). [uBlock Origin](https://ublockorigin.com/) is recommended as it is a general-purpose ad blocker. Please clear your browser's cache after installing the extension.

### Chrome Web Store

Download the extension from the [Chrome Web Store](https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd).

### Firefox Add-ons

Download the extension from [Firefox Add-ons](https://addons.mozilla.org/addon/ttv-lol-pro/).

### Manual installation

1. Download the version for your browser under the "Assets" section of the [latest release](https://github.com/younesaassila/ttv-lol-pro/releases).

1. - **Chrome _(Permanent)_:** Unzip > Go to `chrome://extensions` > Enable developer mode > Load unpacked
   - **Firefox all editions _(Temporary)_:** Go to `about:debugging#/runtime/this-firefox` > Load Temporary Add-on
   - **[Firefox Developer Edition](https://www.mozilla.org/en-US/firefox/developer/) _(Permanent)_:** Go to `about:config` > Set `xpinstall.signatures.required` to `false` > Extensions page > Gear > Install Add-on From File

## Contributing

Contributions are welcome! Please read the [contributing guidelines](CONTRIBUTING.md).

## Credits

Extension maintained by [Younes Aassila (@younesaassila)](https://github.com/younesaassila) [ [GitHub Sponsors](https://github.com/sponsors/younesaassila) ]

Proxies maintained by [Marc Gómez (@zGato)](https://github.com/zGato) [ [PayPal](https://paypal.me/gatogameryt) | [GitHub Sponsors](https://github.com/sponsors/zGato) ]

==> v2.3.7.zip: ttv-lol-pro/README.md <==
<h1 align="center">
  <img alt="Icon" src="src/common/images/brand/icon.png" height="100" width="100" />
  <br />
  TTV LOL PRO
  <br />
</h1>

<div align="center">
  <a href="https://github.com/younesaassila/ttv-lol-pro/issues">
    <img
      alt="GitHub issues"
      src="https://img.shields.io/github/issues/younesaassila/ttv-lol-pro"
    />
  </a>
  <a href="https://github.com/younesaassila/ttv-lol-pro/stargazers">
    <img
      alt="GitHub stars"
      src="https://img.shields.io/github/stars/younesaassila/ttv-lol-pro"
    />
  </a>
  <a
    href="https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd"
  >
    <img
      alt="Chrome Web Store"
      src="https://img.shields.io/chrome-web-store/users/bpaoeijjlplfjbagceilcgbkcdjbomjd"
    />
  </a>
  <a href="https://addons.mozilla.org/addon/ttv-lol-pro/">
    <img alt="Mozilla Add-on" src="https://img.shields.io/amo/dw/ttv-lol-pro" />
  </a>
</div>

<div align="center">
  <a href="https://discord.gg/AmtFTPwsyH">
    <img
      alt="Discord server"
      src="https://dcbadge.vercel.app/api/server/AmtFTPwsyH"
    />
  </a>
</div>

<br />

<div align="center">
  <a
    href="https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd"
  >
    <img
      alt="Chrome Web Store"
      src="src/common/images/badges/chrome_web_store.png"
      height="50"
    />
  </a>
  <a href="https://addons.mozilla.org/addon/ttv-lol-pro/">
    <img
      alt="Firefox Add-ons"
      src="src/common/images/badges/firefox_addons.png"
      height="50"
    />
  </a>
</div>

<br />

> [!NOTE]
> Looking for TTV LOL PRO v1? [Click here](https://github.com/younesaassila/ttv-lol-pro/tree/v1).

TTV LOL PRO removes most livestream ads from Twitch. This is free, don't expect it to be perfect.

TTV LOL PRO is a fork of TTV LOL that:

- uses an improved ad blocking method,
- uses standard HTTP proxies (thus improving proxy compatibility and your privacy),
- adds a stream status widget to the popup,
- lets you whitelist channels,
- lets you use your own proxies.

TTV LOL PRO does not remove banner ads, nor does it remove ads from VODs. For the best experience, we recommend using [uBlock Origin](https://ublockorigin.com/) alongside TTV LOL PRO.

Any questions? Please read the [wiki](https://wiki.cdn-perfprod.com/) first.

## Screenshots

<details>
  <summary>Popup (Firefox)</summary>
  <div align="center">
    <img
      alt="Popup (Firefox)"
      src="https://github.com/younesaassila/ttv-lol-pro/assets/47226184/722b2e22-50b0-4fc7-bd7b-61be2e1b592d"
      height="550"
    />
  </div>
</details>

<details>
  <summary>Options page (Firefox)</summary>
  <div align="center">
    <img
      alt="Options page (Firefox)"
      src="https://github.com/younesaassila/ttv-lol-pro/assets/47226184/83d96fcf-a8b1-4193-9dbe-232bf9d99529"
      height="550"
    />
  </div>
</details>

## Installation

> [!WARNING]
> Please remove any other Twitch-specific ad blocker (this includes the [VAFT](https://github.com/pixeltris/TwitchAdSolutions#scripts) script). [uBlock Origin](https://ublockorigin.com/) is recommended as it is a general-purpose ad blocker. Please clear your browser's cache after installing the extension.

### Chrome Web Store

Download the extension from the [Chrome Web Store](https://chrome.google.com/webstore/detail/ttv-lol-pro/bpaoeijjlplfjbagceilcgbkcdjbomjd).

### Firefox Add-ons

Download the extension from [Firefox Add-ons](https://addons.mozilla.org/addon/ttv-lol-pro/).

### Manual installation

1. Download the version for your browser under the "Assets" section of the [latest release](https://github.com/younesaassila/ttv-lol-pro/releases).

1. - **Chrome _(Permanent)_:** Unzip > Go to `chrome://extensions` > Enable developer mode > Load unpacked
   - **Firefox all editions _(Temporary)_:** Go to `about:debugging#/runtime/this-firefox` > Load Temporary Add-on
   - **[Firefox Developer Edition](https://www.mozilla.org/en-US/firefox/developer/) _(Permanent)_:** Go to `about:config` > Set `xpinstall.signatures.required` to `false` > Extensions page > Gear > Install Add-on From File

## Contributing

Contributions are welcome! Please read the [contributing guidelines](CONTRIBUTING.md).

## Credits

Extension maintained by [Younes Aassila (@younesaassila)](https://github.com/younesaassila) [ [GitHub Sponsors](https://github.com/sponsors/younesaassila) ]

Proxies maintained by [Marc Gómez (@zGato)](https://github.com/zGato) [ [PayPal](https://paypal.me/gatogameryt) | [GitHub Sponsors](https://github.com/sponsors/zGato) ]
